@@ -34,10 +34,11 @@
 #include <fcntl.h>
 #include <dlfcn.h>
 #include <limits.h>
-#include <stdlib.h>
 #include <stdarg.h>
-#include <string.h>
+#include <stddef.h>
 #include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 #include <time.h>
 #include <signal.h>
 #include <inttypes.h>
@@ -199,14 +200,14 @@ get_rdev(const char *nodename)
     static char buf[PATH_MAX];
     static char link[PATH_MAX];
     int name_offset;
-    int i, major, minor, orig_errno;
+    int major, minor, orig_errno;
 
     name_offset = snprintf(buf, sizeof(buf), "%s/dev/.node/", getenv("UMOCKDEV_DIR"));
     buf[sizeof(buf) - 1] = 0;
 
     /* append nodename and replace / with _ */
     strncpy(buf + name_offset, nodename, sizeof(buf) - name_offset - 1);
-    for (i = name_offset; i < sizeof(buf); ++i)
+    for (size_t i = name_offset; i < sizeof(buf); ++i)
 	if (buf[i] == '/')
 	    buf[i] = '_';
 
@@ -373,7 +374,7 @@ netlink_socket(int domain, int type, int protocol)
 }
 
 static int
-netlink_bind(int sockfd, const struct sockaddr *addr, socklen_t addrlen)
+netlink_bind(int sockfd)
 {
     libc_func(bind, int, int, const struct sockaddr *, socklen_t);
 
@@ -397,7 +398,7 @@ netlink_bind(int sockfd, const struct sockaddr *addr, socklen_t addrlen)
 }
 
 static void
-netlink_recvmsg(int sockfd, struct msghdr * msg, int flags, ssize_t ret)
+netlink_recvmsg(int sockfd, struct msghdr * msg, ssize_t ret)
 {
     struct cmsghdr *cmsg;
     struct sockaddr_nl *sender;
@@ -415,8 +416,9 @@ netlink_recvmsg(int sockfd, struct msghdr * msg, int flags, ssize_t ret)
 	/* fake sender credentials to be uid 0 */
 	cmsg = CMSG_FIRSTHDR(msg);
 	if (cmsg != NULL) {
-	    struct ucred *cred = (struct ucred *)CMSG_DATA(cmsg);
-	    cred->uid = 0;
+	    const uid_t uid0 = 0;
+	    /* don't cast into a struct ucred *, as that increases alignment requirement */
+	    memcpy(CMSG_DATA(cmsg) + offsetof(struct ucred, uid), &uid0, sizeof uid0);
 	}
     }
 }
@@ -895,7 +897,7 @@ script_record_open(int fd)
 }
 
 static void
-script_record_connect(int sockfd, const struct sockaddr *addr, socklen_t addrlen, int res)
+script_record_connect(int sockfd, const struct sockaddr *addr, int res)
 {
     size_t i;
 
@@ -952,8 +954,6 @@ script_record_op(char op, int fd, const void *buf, ssize_t size)
     unsigned long delta;
     libc_func(fwrite, size_t, const void *, size_t, size_t, FILE *);
     static char header[100];
-    const unsigned char *cur;
-    int i, r;
 
     if (!fd_map_get(&script_recorded_fds, fd, (const void **)&srinfo))
 	return;
@@ -972,12 +972,13 @@ script_record_op(char op, int fd, const void *buf, ssize_t size)
 		if (srinfo->op != 0)
 		    putc('\n', srinfo->log);
 		snprintf(header, sizeof(header), "%c %lu ", op, delta);
-		r = _fwrite(header, strlen(header), 1, srinfo->log);
+		size_t r = _fwrite(header, strlen(header), 1, srinfo->log);
 		assert(r == 1);
 	    }
 
 	    /* escape ASCII control chars */
-	    for (i = 0, cur = buf; i < size; ++i, ++cur) {
+	    const unsigned char *cur = buf;
+	    for (ssize_t i = 0; i < size; ++i, ++cur) {
 		if (*cur < 32) {
 		    putc('^', srinfo->log);
 		    putc(*cur + 64, srinfo->log);
@@ -1487,7 +1488,7 @@ fread(void *ptr, size_t size, size_t nmemb, FILE * stream)
     size_t res;
 
     res = _fread(ptr, size, nmemb, stream);
-    script_record_op('r', fileno(stream), ptr, (res == 0 && ferror(stream)) ? -1 : res * size);
+    script_record_op('r', fileno(stream), ptr, (res == 0 && ferror(stream)) ? -1 : (ssize_t) (res * size));
     return res;
 }
 
@@ -1498,7 +1499,7 @@ fwrite(const void *ptr, size_t size, size_t nmemb, FILE * stream)
     size_t res;
 
     res = _fwrite(ptr, size, nmemb, stream);
-    script_record_op('w', fileno(stream), ptr, (res == 0 && ferror(stream)) ? -1 : res * size);
+    script_record_op('w', fileno(stream), ptr, (res == 0 && ferror(stream)) ? -1 : (ssize_t) (res * size));
     return res;
 }
 
@@ -1545,7 +1546,7 @@ recvmsg(int sockfd, struct msghdr * msg, int flags)
     libc_func(recvmsg, int, int, struct msghdr *, int);
     ssize_t ret = _recvmsg(sockfd, msg, flags);
 
-    netlink_recvmsg(sockfd, msg, flags, ret);
+    netlink_recvmsg(sockfd, msg, ret);
 
     return ret;
 }
@@ -1569,7 +1570,7 @@ bind(int sockfd, const struct sockaddr *addr, socklen_t addrlen)
     libc_func(bind, int, int, const struct sockaddr *, socklen_t);
     int res;
 
-    res = netlink_bind(sockfd, addr, addrlen);
+    res = netlink_bind(sockfd);
     if (res != UNHANDLED)
 	return res;
 
@@ -1589,6 +1590,12 @@ connect(int sockfd, const struct sockaddr *addr, socklen_t addrlen)
 	TRAP_PATH_LOCK;
 	const char *p = trap_path(sock_path);
 
+	/* could happen with ENOMEM, propagate error */
+	if (!p) {
+	    TRAP_PATH_UNLOCK;
+	    return -1;
+	}
+
 	if (p != sock_path) {
 	    DBG(DBG_NETLINK, "testbed wrapped connect: redirecting Unix socket %s to %s\n", sock_path, p);
 	    trapped_addr.sun_family = AF_UNIX;
@@ -1600,7 +1607,7 @@ connect(int sockfd, const struct sockaddr *addr, socklen_t addrlen)
     }
 
     res = _connect(sockfd, addr, addrlen);
-    script_record_connect(sockfd, addr, addrlen, res);
+    script_record_connect(sockfd, addr, res);
 
     return res;
 }
