@@ -65,7 +65,7 @@ uevent_sender_close(uevent_sender * sender)
 }
 
 static void
-sendmsg_one(uevent_sender * sender, struct msghdr *msg, const char *path)
+sendmsg_one(struct msghdr *msg, const char *path)
 {
     struct sockaddr_un event_addr;
     int fd;
@@ -111,7 +111,7 @@ sendmsg_all(uevent_sender * sender, struct msghdr *msg)
     if (res == 0) {
 	size_t i;
 	for (i = 0; i < gl.gl_pathc; ++i)
-	    sendmsg_one(sender, msg, gl.gl_pathv[i]);
+	    sendmsg_one(msg, gl.gl_pathv[i]);
     } else {
 	/* ensure that we only fail due to that, not due to bad globs */
 	if (res != GLOB_NOMATCH) {
@@ -148,27 +148,27 @@ struct udev_monitor_netlink_header {
     unsigned int filter_tag_bloom_lo;
 };
 
-/* taken from systemd/src/libudev/libudev-util.c */
-static unsigned int
+/* taken from systemd/src/basic/MurmurHash2.c */
+static uint32_t
 string_hash32(const char *str)
 {
     /*
      *  'm' and 'r' are mixing constants generated offline.
      *  They're not really 'magic', they just happen to work well.
      */
-    const unsigned int m = 0x5bd1e995;
+    const uint32_t m = 0x5bd1e995;
     const int r = 24;
     int len = strlen(str);
 
     /* initialize the hash to a 'random' value */
-    unsigned int h = len;
+    uint32_t h = len;
 
     /* mix 4 bytes at a time into the hash */
     const unsigned char *data = (const unsigned char *)str;
 
     while (len >= 4) {
-	unsigned int k = *(unsigned int *)data;
-
+	uint32_t k = 0;
+        memcpy(&k, data, sizeof(uint32_t));
 	k *= m;
 	k ^= k >> r;
 	k *= m;
